%bcond_without testlib

Name:           guava
Version:        18.0
Release:        %mkrel 9
Group:          Development/Java
Summary:        Google Core Libraries for Java
License:        ASL 2.0
URL:            https://github.com/google/guava
BuildArch:      noarch

Source0:        https://github.com/google/guava/archive/v%{version}.tar.gz

Patch0:         %{name}-java8.patch
Patch1:         guava-jdk8-HashMap-testfix.patch

BuildRequires:  maven-local
BuildRequires:  mvn(com.google.code.findbugs:jsr305)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.sonatype.oss:oss-parent:pom:)
%if %{with testlib}
BuildRequires:  mvn(com.google.truth:truth)
BuildRequires:  mvn(junit:junit)
%endif

%description
Guava is a suite of core and expanded libraries that include
utility classes, Google’s collections, io classes, and much
much more.
This project is a complete packaging of all the Guava libraries
into a single jar.  Individual portions of Guava can be used
by downloading the appropriate module and its dependencies.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
API documentation for %{name}.

%if %{with testlib}
%package testlib
Summary:        The guava-testlib subartefact

%description testlib
guava-testlib provides additional functionality for conveinent unit testing
%endif

%prep
%setup -q
%patch0 -p1
%patch1 -p1
find . -name '*.jar' -delete

%pom_disable_module guava-gwt
%if %{without testlib}
%pom_disable_module guava-testlib
%endif
%pom_remove_plugin -r :animal-sniffer-maven-plugin 
%pom_remove_plugin :maven-gpg-plugin
%pom_remove_dep jdk:srczip guava
%pom_remove_dep :caliper guava-tests
%mvn_package :guava-parent guava
%mvn_package :guava-tests __noinstall

# javadoc generation fails due to strict doclint in JDK 1.8.0_45
%pom_remove_plugin -r :maven-javadoc-plugin

%pom_xpath_inject /pom:project/pom:build/pom:plugins/pom:plugin/pom:configuration/pom:instructions "<_nouses>true</_nouses>" guava/pom.xml

%build

%mvn_file :%{name} %{name}
%mvn_alias :%{name} com.google.collections:google-collections com.google.guava:guava-jdk5
# Tests fail on Koji due to insufficient memory,
# see https://bugzilla.redhat.com/show_bug.cgi?id=1332971
%mvn_build -s -f

%install
%mvn_install

%files -f .mfiles-guava
%doc AUTHORS CONTRIBUTORS README*
%license COPYING

%files javadoc -f .mfiles-javadoc
%license COPYING

%if %{with testlib}
%files testlib -f .mfiles-guava-testlib
%endif




%changelog
* Sun May 14 2017 neoclust <neoclust> 18.0-9.mga6
+ Revision: 1101109
- Allow conditional builds without testlib

* Wed Mar 02 2016 neoclust <neoclust> 18.0-6.mga6
+ Revision: 982458
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 18.0-5.mga6
+ Revision: 976273
- First rebuild of the java stack
- sync package guava with fedora

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Mon Jul 13 2015 daviddavid <daviddavid> 18.0-1.mga6
+ Revision: 853554
- sync with fc23 (update to 18.0)
  * Remove maven-javadoc-plugin execution
  * Update upstream website URL
  * Add alias for com.google.guava:guava-jdk5
- fix Group
- fix owner of maven-poms dir

* Wed Oct 15 2014 umeabot <umeabot> 17.0-3.mga5
+ Revision: 743180
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Mon Sep 01 2014 dmorgan <dmorgan> 17.0-1.mga5
+ Revision: 670245
- New version

  + umeabot <umeabot>
    - Mageia 4 Mass Rebuild

* Mon Sep 23 2013 dmorgan <dmorgan> 13.0-4.mga4
+ Revision: 484337
- Build with xmvn

* Tue Jul 30 2013 joequant <joequant> 13.0-3.mga4
+ Revision: 461159
- remove java-nodeps from buildrequires

* Sat Jan 12 2013 umeabot <umeabot> 13.0-2.mga3
+ Revision: 352942
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Sep 09 2012 dmorgan <dmorgan> 13.0-1.mga3
+ Revision: 290821
- New version 13.0

* Mon Dec 12 2011 gil <gil> 09-1.mga2
+ Revision: 181044
- update to 09
  Obsoletes/Provides guava09
  added backward compatibility symlink
  maven build support

* Thu Jan 20 2011 dmorgan <dmorgan> 05-1.mga1
+ Revision: 25595
- Adapt to mageia
- imported package guava


* Wed Jul 14 2010 Hui wang <huwang@redhat.com> - 05-4
- Patch pom

* Fri Jun 18 2010 Hui Wang <huwang@redhat.com> - 05-3
- Fixed jar name in install section
- Removed spaces in description

* Thu Jun 17 2010 Hui Wang <huwang@redhat.com> - 05-2
- Fixed summary
- Fixed description
- Fixed creating symlink insturctions
- add depmap

* Thu Jun 10 2010 Hui Wang <huwang@redhat.com> - 05-1
- Initial version of the package